@@ -9,14 +9,15 @@ cd $srcdir
 
 AUTORECONF=`which autoreconf`
 if test -z $AUTORECONF; then
-        echo "*** No autoreconf found, please intall it ***"
+        echo "*** No autoreconf found, please install it ***"
         exit 1
 fi
 
 GTKDOCIZE=`which gtkdocize`
 if test -z $GTKDOCIZE; then
-        echo "*** No GTK-Doc found, please install it ***"
-        exit 1
+        echo "*** No GTK-Doc found, documentation won't be generated ***"
+else
+        gtkdocize || exit $?
 fi
 
 # create dummy */Makefile.am.features and ChangeLog to make automake happy
@@ -24,8 +25,7 @@ fi
 > src/Makefile.am.features
 touch ChangeLog
 
-gtkdocize || exit $?
-autoreconf --force --install --verbose || exit $?
+autoreconf --install --verbose || exit $?
 
 cd $ORIGDIR
 test -n "$NOCONFIGURE" || "$srcdir/configure" "$@"
